@@ -27,21 +27,13 @@
 DlgSpecChar::DlgSpecChar(QWidget *parent, const QFont &font, const QChar &chr) : QDialog(parent)
 {
   setWindowTitle( i18nc("@title:window select character dialog", "Select Character") );
-  QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Cancel);
   QWidget *mainWidget = new QWidget(this);
-  QVBoxLayout *mainLayout = new QVBoxLayout;
-  setLayout(mainLayout);
+  QVBoxLayout *mainLayout = new QVBoxLayout(this);
   mainLayout->addWidget(mainWidget);
-  QPushButton *user1Button = new QPushButton;
-  buttonBox->addButton(user1Button, QDialogButtonBox::ActionRole);
-  connect(buttonBox, &QDialogButtonBox::accepted, this, &QDialog::accept);
-  connect(buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
-  //PORTING SCRIPT: WARNING mainLayout->addWidget(buttonBox) must be last item in layout. Please move it.
-  mainLayout->addWidget(buttonBox);
-  user1Button->setDefault(true);
   setModal(true);
 
-  m_charSelect = new KCharSelect(this, 0);
+
+  m_charSelect = new KCharSelect(this, nullptr);
   m_charSelect->setCurrentChar(chr);
   m_charSelect->setCurrentFont(font);
   connect(m_charSelect, &KCharSelect::charSelected,this, &DlgSpecChar::slotDoubleClicked);
@@ -49,6 +41,15 @@ DlgSpecChar::DlgSpecChar(QWidget *parent, const QFont &font, const QChar &chr) :
   m_charSelect->setFocus();
   mainLayout->addWidget(m_charSelect);
 
+  QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Cancel, this);
+  QPushButton *user1Button = new QPushButton;
+  buttonBox->addButton(user1Button, QDialogButtonBox::ActionRole);
+  connect(buttonBox, &QDialogButtonBox::accepted, this, &QDialog::accept);
+  connect(buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
+  mainLayout->addWidget(buttonBox);
+  user1Button->setDefault(true);
+
+
   user1Button->setText(i18nc("@action:button", "&Select"));
   user1Button->setToolTip(i18nc("@info:tooltip", "Select this character"));
   connect(user1Button,&QAbstractButton::clicked,this,&DlgSpecChar::slotUser1);
